@@ -73,7 +73,7 @@ class ContentManager:
                 break
         else:
             if default is None:
-                raise Exception('Couldnt match accepts with supported formats: %s' % accept)
+                raise Exception('Couldnt match accepts with supported formats: %s' % accepts)
         image = Image.open(io.BytesIO(img))
         with io.BytesIO() as output:
             image.save(output, format=new_format)
@@ -129,7 +129,6 @@ class ContentManager:
                 if accepts:
                     body = self.convert_by_accepts(body, accepts)
                     content_type = self.__magic.from_buffer(body)
-            body = base64.b64encode(body)
             isBase64Encoded = True
         h["Content-Type"] = content_type
         r = ResponseWithBinary(body=body, status_code=status_code, headers=h)
