@@ -23,10 +23,12 @@ def ex_multipart(app:Chalice) -> dict:
     parts = {}
     for part in MultipartDecoder(app.current_request.raw_body, app.current_request.headers['content-type']).parts:
         raw_name = str(part.headers[b'Content-Disposition'], 'utf-8')
+        name = None
         filename = None
         if "name" in raw_name:
-            raw_name = ex_name(raw_name)
+            name = ex_name(raw_name)
         if "filename" in raw_name:
             filename = ex_filename(raw_name)
-        parts[raw_name] = {'data': part.content, 'filename': filename}
+        if name:
+            parts[name] = {'data': part.content, 'filename': filename}
     return parts
\ No newline at end of file
